"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BootstrapApplication = void 0;
const express_1 = __importDefault(require("express"));
const typeorm_1 = require("typeorm");
const tsyringe_1 = require("tsyringe");
class BootstrapApplication {
    // private controllers: IController[];
    constructor(dependencyContainer) {
        this.initiliazeExpressRoutes = () => {
            for (let controller of this.controllerManager.getControllers()) {
                this.application.use('/', controller.getRouter());
            }
        };
        this.getServer = () => {
            return this.application ? this.application : (this.application = express_1.default());
        };
        this.listen = async () => {
            await this.orm.startTypeorm();
            const connection = typeorm_1.getConnection(this.orm.getConnectionName());
            tsyringe_1.container.register(typeorm_1.Connection, { useValue: connection });
            this.middlewares.initializeMiddlewares(this.application);
            this.initiliazeExpressRoutes();
            this.application.listen(3001, () => {
                console.log(`⚡️ App listening on the port ${3001}`);
            });
        };
        this.application = express_1.default();
        this.orm = dependencyContainer.orm;
        this.middlewares = dependencyContainer.middlewares;
        this.controllerManager = dependencyContainer.controllerManager;
    }
}
exports.BootstrapApplication = BootstrapApplication;
